[java-identity-provider COMMIT] in /trunk: idp-attribute-resolver-api/src/main/java/net/shibboleth/idp/attribute/reso...

noreply at shibboleth.net noreply at shibboleth.net
Mon May 12 03:54:06 EDT 2014


Author: rdw
Date: Mon May 12 03:54:06 2014
New Revision: 5907

URL: http://svn.shibboleth.net/view/java-identity-provider?rev=5907&view=rev
Log:
IDP-406 The predicates which get attached to reolvers and encoders are refered to by the attibute "activationConditionRef".  Change the field, setter & getteer in the base plugin class to match.

Modified:
    trunk/idp-attribute-resolver-api/src/main/java/net/shibboleth/idp/attribute/resolver/AbstractResolverPlugin.java
    trunk/idp-attribute-resolver-api/src/main/java/net/shibboleth/idp/attribute/resolver/ResolvedAttributeDefinition.java
    trunk/idp-attribute-resolver-api/src/main/java/net/shibboleth/idp/attribute/resolver/ResolvedDataConnector.java
    trunk/idp-attribute-resolver-api/src/main/java/net/shibboleth/idp/attribute/resolver/ResolverPlugin.java
    trunk/idp-attribute-resolver-api/src/test/java/net/shibboleth/idp/attribute/resolver/AbstractResolverPluginTest.java
    trunk/idp-attribute-resolver-api/src/test/java/net/shibboleth/idp/attribute/resolver/ResolvedAttributeDefinitionTest.java
    trunk/idp-attribute-resolver-api/src/test/java/net/shibboleth/idp/attribute/resolver/ResolvedDataConnectorTest.java
    trunk/idp-attribute-resolver-spring/src/main/java/net/shibboleth/idp/attribute/resolver/spring/BaseResolverPluginParser.java
    trunk/idp-attribute-resolver-spring/src/main/java/net/shibboleth/idp/attribute/resolver/spring/enc/BaseAttributeEncoderParser.java
    trunk/idp-attribute-resolver-spring/src/test/resources/net/shibboleth/idp/attribute/resolver/spring/attribute-resolver-selective-navigate.xml
    trunk/idp-attribute-resolver-spring/src/test/resources/net/shibboleth/idp/attribute/resolver/spring/attribute-resolver-selective.xml
    trunk/idp-attribute-resolver-spring/src/test/resources/net/shibboleth/idp/attribute/resolver/spring/enc/saml2StringConditional.xml
    trunk/idp-schema/src/main/resources/schema/shibboleth-attribute-resolver.xsd

Modified: trunk/idp-attribute-resolver-api/src/main/java/net/shibboleth/idp/attribute/resolver/AbstractResolverPlugin.java
URL: http://svn.shibboleth.net/view/java-identity-provider/trunk/idp-attribute-resolver-api/src/main/java/net/shibboleth/idp/attribute/resolver/AbstractResolverPlugin.java?rev=5907&r1=5906&r2=5907&view=diff
==============================================================================
--- trunk/idp-attribute-resolver-api/src/main/java/net/shibboleth/idp/attribute/resolver/AbstractResolverPlugin.java (original)
+++ trunk/idp-attribute-resolver-api/src/main/java/net/shibboleth/idp/attribute/resolver/AbstractResolverPlugin.java Mon May 12 03:54:06 2014
@@ -68,7 +68,7 @@
             new ParentContextLookup<>();
 
     /** Criterion that must be met for this plugin to be active for the given request. */
-    @Nullable private Predicate<ProfileRequestContext> activationCriteria;
+    @Nullable private Predicate<ProfileRequestContext> activationCondition;
 
     /** IDs of the {@link ResolutionPlugIn}s this plug-in depends on. */
     @Nonnull @NonnullElements private Set<ResolverPluginDependency> dependencies = Collections.emptySet();
@@ -115,24 +115,20 @@
         propagateResolutionExceptions = propagate;
     }
 
-    /**
-     * Gets the criteria that must be met for this plugin to be active for a given request.
-     * 
-     * @return criteria that must be met for this plugin to be active for a given request, never null
-     */
-    @Override @Nullable public Predicate<ProfileRequestContext> getActivationCriteria() {
-        return activationCriteria;
-    }
-
-    /**
-     * Sets the criteria that must be met for this plugin to be active for a given request.
-     * 
-     * @param criteria criteria that must be met for this plugin to be active for a given request
-     */
-    public void setActivationCriteria(@Nonnull final Predicate<ProfileRequestContext> criteria) {
-        ComponentSupport.ifInitializedThrowUnmodifiabledComponentException(this);
-        ComponentSupport.ifDestroyedThrowDestroyedComponentException(this);
-        activationCriteria = Constraint.isNotNull(criteria, "Activiation criteria cannot be null");
+    /** {@inheritDoc} */
+    @Override @Nullable public Predicate<ProfileRequestContext> getActivationCondition() {
+        return activationCondition;
+    }
+
+    /**
+     * Sets the predicate which defines whether this plugin is active for a given request.
+     * 
+     * @param pred what to set
+     */
+    public void setActivationCondition(@Nonnull final Predicate<ProfileRequestContext> pred) {
+        ComponentSupport.ifInitializedThrowUnmodifiabledComponentException(this);
+        ComponentSupport.ifDestroyedThrowDestroyedComponentException(this);
+        activationCondition = Constraint.isNotNull(pred, "Activiation condition cannot be null");
     }
 
     /**
@@ -182,9 +178,9 @@
 
         Constraint.isNotNull(resolutionContext, "AttributeResolutionContext cannot be null");
 
-        if (null != activationCriteria) {
+        if (null != activationCondition) {

[... 255 lines stripped ...]


More information about the commits mailing list